@@ -27,12 +27,14 @@ class Reactor(object):
         'debug': False,
         'graphite_url': 'http://localhost',
         'interval': '10minute',
+        'history_size': 60,
         'repeat_interval': '2hour',
         'logging': 'info',
         'method': 'average',
         'normal_handlers': ['log', 'smtp'],
         'pidfile': None,
         'prefix': '[BEACON]',
+        'send_initial': False,
         'warning_handlers': ['log', 'smtp'],
     }
 
